@@ -79,7 +79,12 @@ def profile(decorated_function: Callable) -> Callable:
                   required=False,
                   is_flag=False,
                   help='yojenkins profile name or profile as JSON text')
-    @click.option('--token', type=str, required=False, is_flag=False, help='Authentication API token to use')
+    @click.option('--token',
+                  type=str,
+                  required=False,
+                  is_flag=False,
+                  envvar="YOJENKINS_TOKEN",
+                  help='Authentication API token to use')
     @functools.wraps(decorated_function)
     def wrapper(*args, **kwargs):
         return decorated_function(*args, **kwargs)
