@@ -172,11 +172,13 @@ class Auth:
 
         return generated_token
 
-    def profile_add_new_token(self, profile_name: str) -> str:
+    def profile_add_new_token(self, profile_name: str, token: str = "", password: str = "") -> str:
         """Update the specified credentials profile with a new server API token
 
         Args:
             profile_name : Name of the profile as specified in the credentials file
+            token:         Add this provided API token instead of generating a new one
+            password:      Password for referenced account in profile
 
         Returns:
             Server API Token
@@ -197,7 +199,6 @@ class Auth:
 
         profile_info = profiles[profile_name]
         logger.debug(f'Profile "{profile_name}" loaded')
-        logger.debug(f'Profile info: {profile_info}')
 
         # Generate a API token name (seen in Jenkins UI)
         token_name = f'yojenkins_{datetime.now().strftime("%m-%d-%Y_%I-%M-%S")}'
@@ -214,8 +215,15 @@ class Auth:
         else:
             username = profile_info['username']
 
-        # Generate and store the API token
-        api_token = self.generate_token(token_name=token_name, server_base_url=server_url, username=username)
+        # Use provided or generate and store the API token
+        if token:
+            logger.debug('Using API token provided with --token CLI option ...')
+            api_token = token
+        else:
+            api_token = self.generate_token(token_name=token_name,
+                                            server_base_url=server_url,
+                                            username=username,
+                                            password=password)
         profiles[profile_name]['api_token'] = api_token
 
         success = self._update_profiles(profiles=profiles)
@@ -678,7 +686,10 @@ class Auth:
             fail_out('Failed to find profile key "jenkins_server_url". Profile may not have loaded correctly')
         request_success = self.rest.request(target=request_url, is_endpoint=False, request_type='head')[2]
         if not request_success:
-            fail_out('Failed server authentication with specified user credentials')
+            messages = ['Failed server authentication with specified user credentials']
+            if "YOJENKINS_TOKEN" in os.environ:
+                messages.append("   - NOTE: Environmental variable YOJENKINS_TOKEN is defined")
+            failures_out(messages)
         logger.debug('Successfully authenticated with specified user credentials')
 
         return True
